/*
   To test this program, first build the SuppliersParts database by
   running the file SuppliersParts.cmd, which will use the sqlite3.exe
   program to execute the SQL commands in SuppliersParts.sql.

   Second, compile this program with the command

    c:\MinGW\bin\gcc -Wall -g -o suppliers-parts.exe suppliers-parts.c sqlite3.o

   I built the object file sqlite3.o using gcc, so you need to
   compile and link this program using gcc.

   You can download the MinGW version of gcc using the following URL.

        http://downloads.sourceforge.net/mingw/MinGW-3.1.0-1.exe
*/
#include <stdio.h>
#include "sqlite3.h"

/* Each call to callback() handles one tuple from the table that is the query result */
static int callback(void *NotUsed, int argc, char **argv, char **azColName)
{
   int i;
   /* Iterate through the attributes in this tuple */
   for(i = 0; i < argc; i++)
   {
      printf("%s=%s\t", azColName[i], argv[i] ? argv[i] : "NULL");
   }
   printf("\n");
   return 0;
}

int main()
{
   sqlite3 *db;
   char *zErrMsg = 0;
   int rc;

   /* Try to open the database. */
   rc = sqlite3_open("SuppliersParts.db", &db);
   if( rc )
   {
      fprintf(stderr, "Can't open database: %s\n", sqlite3_errmsg(db));
      sqlite3_close(db);
      return 1;
   }

   /* Execute an SQL statement on the open database.
      The call back function will handle the resulting table. */
   rc = sqlite3_exec(db, "select * from S", callback, 0, &zErrMsg);
   if( rc != SQLITE_OK )
   {
      fprintf(stderr, "SQL error: %s\n", zErrMsg);
      sqlite3_free(zErrMsg);
      sqlite3_close(db);
      return 1;
   }

   printf("Done processing SQL query.\n");

   sqlite3_close(db);
   return 0;
}
